@@ -10,9 +10,8 @@ logger = getLogger()
 
 class RootPermissions(object):
     def _nt(self):
-        from ctypes import windll
-        # http://msdn.microsoft.com/en-us/library/windows/desktop/bb776463(v=vs.85).aspx
-        return windll.shell32.IsUserAnAdmin()
+        from .windows import is_admin
+        return is_admin()
 
     def _posix(self):
         return os.getuid() == 0
